pype32.directories.ImageImportDescriptorMetaData

Package pype32 :: Module directories :: Class ImageImportDescriptorMetaData |
[hide private]
[frames] | no frames]

# Class ImageImportDescriptorMetaData

source code

                     object --+
                              |
    baseclasses.BaseStructClass --+
                                  |
                                 ImageImportDescriptorMetaData

ImageImportDescriptorMetaData object.

Instance Methods | [hide private]
__init__(self, shouldPack=True) Class used to store metadata from the ImageImportDescriptor object. | source code
getType(self) Returns consts.IID_METADATA. | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__subclasshook__`
Inherited from baseclasses.BaseStructClass
__len__(self) | source code
__str__(self) str(x) | source code
dict |
getFields(self) Returns all the class attributues. | source code
sizeof(self) | source code

Instance Variables | [hide private]
| moduleName String moduleName.
| numberOfImports DWORD numberOfImports.

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, shouldPack=True) (Constructor) | source code
Class used to store metadata from the ImageImportDescriptor object. Parameters: `shouldPack` (bool) - (Optional) If set to c{True}, the object will be packed. If set to `False`, the object won't be packed. Overrides: object.__init__

### getType(self) | source code
Returns consts.IID_METADATA. Raises: `NotImplementedError` - The method wasn't implemented in the inherited class. Overrides: baseclasses.BaseStructClass.getType